package com.caimei.service;

import com.caimei.model.ResponseJson;

import java.math.BigDecimal;
import java.util.List;
import java.util.Map;

/**
 * Description
 *
 * @author : Charles
 * @date : 2020/3/21
 */
public interface OrderSubmitService {
    /**
     * 商品结算
     *
     * @param productIds 商品ID串用逗号隔开。
     * @param organizeId 组织id。
     * @param storeId   门店id。
     * @return
     */
    ResponseJson<Map<String, Object>> orderConfirm(String productIds, Integer organizeId, Integer storeId);

    /**
     * 提交订单
     *
     * @param organizeId
     * @param addressId
     * @param orderInfo
     * @param payInfo
     * @param orderInvoice
     * @return
     */
    ResponseJson<Map<String, String>> orderSubmit(Integer organizeId, Integer storeId, Integer addressId, List<Map<String, Object>> orderInfo, Map<String, Object> payInfo, Map<String, Object> orderInvoice);

    /**
     * 订单余额抵扣
     * @param orderId 订单id
     * @return
     */
    ResponseJson<Map<String, Object>> balanceDeduction(Integer orderId);

    /**
     * 保存余额抵扣记录
     * @param balancePayFee 余额支付金额
     * @param orderId       订单id
     * @param userId        用户id
     */
    void saveBalanceRecord(BigDecimal balancePayFee, Integer orderId, Integer userId);

    /**
     * 保存收款记录
     * @param balancePayFee 余额支付金额
     * @param orderId       订单id
     */
    void saveDiscernReceipt(BigDecimal balancePayFee, Integer orderId);

    /**
     * 订单支付,效验付款规则
     * @param orderId
     * @return
     */
    ResponseJson<Map<String, Object>> paymentValidation(Integer orderId);
}
