package com.caimei.service.impl;

import com.caimei.mapper.AddressMapper;
import com.caimei.mapper.UserMapper;
import com.caimei.model.ResponseJson;
import com.caimei.model.po.CmUserInvoiceInfoPo;
import com.caimei.model.vo.AddressVo;
import com.caimei.model.vo.CityVo;
import com.caimei.model.vo.ProvinceVo;
import com.caimei.model.vo.TownVo;
import com.caimei.service.AddressService;
import com.github.pagehelper.PageHelper;
import com.github.pagehelper.PageInfo;
import org.springframework.stereotype.Service;

import javax.annotation.Resource;
import java.util.List;

/**
 * Description
 *
 * @author : plf
 * @date : 2021/3/25
 */
@Service
public class AddressServiceImpl implements AddressService {
    @Resource
    private AddressMapper addressMapper;
    @Resource
    private UserMapper userMapper;

    @Override
    public ResponseJson<PageInfo<AddressVo>> findAddress(Integer storeId, Integer pageNum, Integer pageSize) {
        PageHelper.startPage(pageNum, pageSize);
        List<AddressVo> addressList = addressMapper.findAddress(storeId);
        PageInfo<AddressVo> pageInfo = new PageInfo<>(addressList);
        return ResponseJson.success(pageInfo);
    }

    @Override
    public ResponseJson<AddressVo> saveAddress(AddressVo address) {
        if (address.getDefaultFlag() != null && "1".equals(address.getDefaultFlag())) {
            AddressVo addressVo = addressMapper.findDefaultAddress(address.getStoreId());
            if (addressVo != null) {
                addressVo.setDefaultFlag("0");
                addressMapper.updateAddress(addressVo);
            }
        }
        if (address.getAddressId() == null) {
            addressMapper.insertAddress(address);
        } else {
            addressMapper.updateAddress(address);
        }
        return ResponseJson.success(address);
    }

    @Override
    public ResponseJson<String> deleteAddress(Integer addressId) {
        addressMapper.deleteAddress(addressId);
        return ResponseJson.success("删除成功");
    }

    @Override
    public ResponseJson<String> defaultAddress(Integer storeId, Integer addressId) {
        AddressVo address = addressMapper.findDefaultAddress(storeId);
        if (null != address) {
            address.setDefaultFlag("0");
            addressMapper.updateAddress(address);
        }
        addressMapper.updateDefaultAddress(addressId);
        return ResponseJson.success("操作成功");
    }

    @Override
    public ResponseJson<List<ProvinceVo>> address() {
        List<ProvinceVo> list = addressMapper.findAllProvince();
        for (ProvinceVo province : list) {
            List<CityVo> cityList = addressMapper.findAllCity(province.getProvinceId());
            province.setCityList(cityList);
            if (cityList != null && cityList.size() > 0) {
                for (CityVo city : cityList) {
                    List<TownVo> townList = addressMapper.findAllTown(city.getCityId());
                    city.setTownList(townList);
                }
            }
        }
        return ResponseJson.success(list);
    }

    @Override
    public ResponseJson<String> saveInvoice(CmUserInvoiceInfoPo invoice) {
        Integer userId = userMapper.getUserIdByOrganizeId(invoice.getOrganizeId());
        if (null == userId) {
            return ResponseJson.error("用户不存在", null);
        }
        invoice.setUserId(userId.longValue());
        if (invoice.getId() == null) {
            addressMapper.insertInvoice(invoice);
        } else {
            addressMapper.updateInvoice(invoice);
        }
        return ResponseJson.success("操作成功");
    }

    @Override
    public ResponseJson<CmUserInvoiceInfoPo> findInvoice(Integer organizeId) {
        Integer userId = userMapper.getUserIdByOrganizeId(organizeId);
        if (null == userId) {
            return ResponseJson.error("用户不存在", null);
        }
        CmUserInvoiceInfoPo invoice = addressMapper.findInvoice(userId);
        return ResponseJson.success(invoice);
    }
}
